@@ -15,7 +15,7 @@ fi
 sleep 2
 if [ -z "$(pidof qtlockscreen)" ]; then
     echo "Restarting qtlockscreen (didn't respawn)"
-    bg qtlockscreen || { exit 1; }
+    qtlockscreen &
 fi
 
 echo "Done"
\ No newline at end of file
